@@ -18,8 +18,6 @@
 #include <ppltasks.h>
 #include <windows.h>
 
-using namespace Windows::Foundation;
-
 K_PLUGIN_CLASS_WITH_JSON(MprisControlPlugin, "kdeconnect_mpriscontrol.json")
 
 namespace
@@ -30,12 +28,17 @@ const QString DEFAULT_PLAYER =
 
 MprisControlPlugin::MprisControlPlugin(QObject *parent, const QVariantList &args)
     : KdeConnectPlugin(parent, args)
+    , sessionManager(NULL)
 {
     try {
-        auto sessionManager = GlobalSystemMediaTransportControlsSessionManager::RequestAsync().get();
-        sessionManager.SessionsChanged([this](GlobalSystemMediaTransportControlsSessionManager, SessionsChangedEventArgs) {
-            this->updatePlayerList();
-        });
+        sessionManager = GlobalSystemMediaTransportControlsSessionManager::RequestAsync().get();
+        if (sessionManager) {
+            sessionManager.SessionsChanged([this](GlobalSystemMediaTransportControlsSessionManager, SessionsChangedEventArgs) {
+                this->updatePlayerList();
+            });
+        } else {
+            qCWarning(KDECONNECT_PLUGIN_MPRISCONTROL) << "Failed to obtain Session Manager.";
+        }
     } catch (winrt::hresult_error e) {
         qCWarning(KDECONNECT_PLUGIN_MPRISCONTROL) << "Failed to register mediaSessionsChanged listener";
     }
@@ -54,6 +57,17 @@ std::optional<QString> MprisControlPlugin::getPlayerName(const GlobalSystemMedia
     return entry.key();
 }
 
+TimeSpan MprisControlPlugin::getPlayerPosition(const GlobalSystemMediaTransportControlsSession &player)
+{
+    auto playbackInfo = player.GetPlaybackInfo();
+    bool isPlaying = playbackInfo.PlaybackStatus() == GlobalSystemMediaTransportControlsSessionPlaybackStatus::Playing;
+    auto position = player.GetTimelineProperties().Position();
+    if (isPlaying)
+        return position + winrt::clock::now() - player.GetTimelineProperties().LastUpdatedTime();
+    else
+        return position;
+}
+
 QString MprisControlPlugin::randomUrl()
 {
     const QString VALID_CHARS = QStringLiteral("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ");
@@ -76,9 +90,9 @@ void MprisControlPlugin::sendMediaProperties(const std::variant<NetworkPacket, Q
     if (packetOrName.index() == 1)
         np.set(QStringLiteral("player"), std::get<1>(packetOrName));
 
-    QString title = QStringLiteral("N/A");
-    QString artist = QStringLiteral("N/A");
-    QString album = QStringLiteral("N/A");
+    QString title = i18n("N/A");
+    QString artist = i18n("N/A");
+    QString album = i18n("N/A");
     // Calling GlobalSystemMediaTransportControlsSession.TryGetMediaPropertiesAsync().get()
     // can trigger a RuntimeError: Element not found in some scenarios.
     // See: https://bugs.kde.org/show_bug.cgi?id=502269
@@ -438,7 +452,7 @@ void MprisControlPlugin::receivePacket(const NetworkPacket &np)
     if (np.has(QStringLiteral("Seek"))) {
         TimeSpan offset = std::chrono::microseconds(np.get<int>(QStringLiteral("Seek")));
         qWarning(KDECONNECT_PLUGIN_MPRISCONTROL) << "Seeking" << offset.count() << "ns to" << name;
-        player.TryChangePlaybackPositionAsync((player.GetTimelineProperties().Position() + offset).count()).get();
+        player.TryChangePlaybackPositionAsync((getPlayerPosition(player) + offset).count()).get();
     }
 
     if (np.has(QStringLiteral("SetPosition"))) {
