@@ -24,8 +24,8 @@ K_PLUGIN_CLASS_WITH_JSON(SftpPlugin, "kdeconnect_sftp.json")
 
 SftpPlugin::SftpPlugin(QObject *parent, const QVariantList &args)
     : KdeConnectPlugin(parent, args)
-    , deviceId(device()->id())
     , m_mounter(nullptr)
+    , deviceId(device()->id())
 {
     addToDolphin();
     qCDebug(KDECONNECT_PLUGIN_SFTP) << "Created device:" << device()->name();
@@ -120,6 +120,12 @@ void SftpPlugin::receivePacket(const NetworkPacket &np)
         return;
     }
 
+    // if a packet arrives before mounting or after the mount timed out, ignore it
+    if (!m_mounter) {
+        qCDebug(KDECONNECT_PLUGIN_SFTP) << "Received network packet but no mount is active, ignoring";
+        return;
+    }
+
     m_mounter->onPacketReceived(np);
 
     remoteDirectories.clear();
